--------------------------------------------------------------------------------
-- Low Orbit Ion Cannon
-- version 1.0
-- by Kifferopa
--------------------------------------------------------------------------------

-- Setup Tables
if kifferopa==nil then kifferopa={} end
kifferopa.loic={}
kifferopa.loic.ray={}

-- Load & Prepare Ressources
kifferopa.loic.gfx_wpn=loadgfx("weapons/rc.bmp")							-- Weapon Image
setmidhandle(kifferopa.loic.gfx_wpn)
kifferopa.loic.gfx_icon=loadgfx("weapons/loic_icon.png")				-- Weapon Icon
setmidhandle(kifferopa.loic.gfx_icon)
kifferopa.loic.gfx_pro=loadgfx("weapons/lasershot.png")					-- Projectile Image
setmidhandle(kifferopa.loic.gfx_pro)
kifferopa.loic.sfx_attack=loadsfx("loic.wav")						-- Attack Sound

--------------------------------------------------------------------------------
-- Weapon: Low Orbit Ion Cannon 
--------------------------------------------------------------------------------

kifferopa.loic.id=addweapon("kifferopa.loic","Low-Orbit Ion Cannon",kifferopa.loic.gfx_icon,0,3)

function kifferopa.loic.draw()													-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(kifferopa.loic.gfx_wpn,7,0)
	-- HUD Positioning
	if weapon_shots<=2 and weapon_position==0 then
		hudpositioning(pos_invisible)
	end
end

function kifferopa.loic.attack(attack)									-- Attack
	if (weapon_shots<=0) and (weapon_position==1) then
		-- No more weapon switching!
		useweapon(0)
		weapon_shots=weapon_shots+1
		weapon_position=0
		-- Attack
		for i=1,10 do
			pid=createprojectile(kifferopa.loic.ray.id)
			projectiles[pid]={}
			projectiles[pid].x=weapon_x
			projectiles[pid].y=-1000-i*500
			projectiles[pid].sx=0
			projectiles[pid].sy=50.0
			projectiles[pid].timer=-100*(i-1)
			projectiles[pid].soundplayed=false
			if(i==1) then
				projectiles[pid].follow=true
			else
				projectiles[pid].follow=false
			end
		end
		
		endturn()
	end
end

--------------------------------------------------------------------------------
-- Projectile: Ion Ray 
--------------------------------------------------------------------------------

kifferopa.loic.ray.id=addprojectile("kifferopa.loic.ray")	-- Add Projectile

function kifferopa.loic.ray.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(0,255,255)
	setscale(5,5)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(kifferopa.loic.gfx_pro,projectiles[id].x,projectiles[id].y-50)
end

function kifferopa.loic.ray.die(id)
	-- particle effects
	particle(p_smoke,projectiles[id].x,projectiles[id].y)
	particlefadealpha(0.006)
	particle(p_muzzle,projectiles[id].x,projectiles[id].y)
	particlefadealpha(1.2)
	particlesize(1.5,1.5)
	particlecolor(0,255,255)
	particlefadealpha(0.005)
	for j=1,30,1 do
		particle(p_lightpuff,projectiles[id].x,projectiles[id].y)
		particlespeed(math.random(-20,20)*0.2,math.random(-20,20)*0.2)
		particlefadealpha(0.03)
		particlesize(math.random(40,70)*0.15,math.random(40,70)*0.15)
		particlecolor(0,255,255)
	end
	for i=1,5 do
		particle(p_spark,projectiles[id].x,projectiles[id].y)
		particlecolor(0,255,255)
		particlefadealpha(0.01)
		particlesize(1.0,1.0)
	end
	-- cause damage
	arealdamage(projectiles[id].x,projectiles[id].y,70,25)
	-- destroy terrain
	terrainexplosion(projectiles[id].x,projectiles[id].y,40,1)
--	terraincircle(projectiles[id].x,projectiles[id].y,40,0x00000000)
	-- crater
	grey=math.random(0,40)
	alpha=math.random(7,9)*0.1
	blue=50+grey
	green=25+grey
	terrainalphaimage(gfx_crater150,projectiles[id].x,projectiles[id].y,alpha,grey,green,blue)
	scroll(projectiles[id].x,projectiles[id].y+projectiles[id].sy)
	freeprojectile(id)
end

function kifferopa.loic.ray.update(id)							-- Update
	-- draw particle tail
	particle(p_lightpuff,projectiles[id].x,projectiles[id].y)
	particlespeed(math.random(-5,5)*0.1,math.random(-5,5)*0.1)
	particlefadealpha(0.05)
	particlesize(math.random(20,40)*0.1,math.random(20,40)*0.1)
	particlecolor(0,255,255)

	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))



	-- timer (remove projectile after 10 seconds)
	projectiles[id].timer=projectiles[id].timer+1

	if projectiles[id].y>=-1000 and projectiles[id].soundplayed == false then
		playsound(kifferopa.loic.sfx_attack)
		projectiles[id].soundplayed = true
	end
	if projectiles[id].timer>500 then
		freeprojectile(id)
		return 1
	end

	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/100)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		-- Move X
		projectiles[id].x=projectiles[id].x+msubx
		if collision(col30x30, projectiles[id].x, projectiles[id].y, 1, 1, 1)==1 then
			kifferopa.loic.ray.die(id)	
			return
		else
			projectiles[id].ignore=0
		end
		-- Move Y
		projectiles[id].y=projectiles[id].y+msuby
		if collision(col30x30, projectiles[id].x,projectiles[id].y,1,1,1)==1 then
			kifferopa.loic.ray.die(id)
			return
		else
			projectiles[id].ignore=0
		end	
		
		-- Water
		if (projectiles[id].y)>getwatery()+10 then
			-- Effects
			playsound(sfx_steam)
			-- Free projectile
			freeprojectile(id)
			return
		end
	end
	-- Scroll to projectile
	if projectiles[id].follow==true then
		scroll(projectiles[id].x,projectiles[id].y+projectiles[id].sy)
	end
end
